@@ -22,15 +22,9 @@ EVENT_CHAOS_PERCENTAGE_SIMULATE_FAILURES_KEY = (
 class RabbitMqEventChaos(IEventChaos):
     def __init__(
         self,
-        percentage_simulate_nack: Optional[float] = os.environ.get(
-            EVENT_CHAOS_PERCENTAGE_SIMULATE_NACK_KEY
-        ),
-        delay_before_even_handler_second: Optional[float] = os.environ.get(
-            EVENT_CHAOS_DELAY_BEFORE_EVENT_HANDLER_SECONDS_KEY
-        ),
-        percentage_simulate_failures: Optional[float] = os.environ.get(
-            EVENT_CHAOS_PERCENTAGE_SIMULATE_FAILURES_KEY
-        ),
+        percentage_simulate_nack: Optional[float] = None,
+        delay_before_even_handler_second: Optional[float] = None,
+        percentage_simulate_failures: Optional[float] = None,
     ):
         """
         Parameters
@@ -42,9 +36,38 @@ class RabbitMqEventChaos(IEventChaos):
         percentage_simulate_failures
             Percentage of simulate failures [0.0 -> 1.0]. Where 1.0 simulate always a failure on handlers.
         """
-        self.percentage_simulate_nack = percentage_simulate_nack
-        self.delay_before_even_handler_second = delay_before_even_handler_second
-        self.percentage_simulate_failures = percentage_simulate_failures
+        self._set_percentage_simulate_nack(percentage_simulate_nack)
+        self._set_delay_before_even_handler_second(delay_before_even_handler_second)
+        self._set_percentage_simulate_failures(percentage_simulate_failures)
+
+    def _set_percentage_simulate_nack(self, percentage_simulate_nack):
+        if percentage_simulate_nack is None:
+            percentage_simulate_nack = os.environ.get(
+                EVENT_CHAOS_PERCENTAGE_SIMULATE_NACK_KEY
+            )
+        self.percentage_simulate_nack = self._float(percentage_simulate_nack)
+
+    def _set_delay_before_even_handler_second(self, delay_before_even_handler_second):
+        if delay_before_even_handler_second is None:
+            delay_before_even_handler_second = os.environ.get(
+                EVENT_CHAOS_DELAY_BEFORE_EVENT_HANDLER_SECONDS_KEY
+            )
+        self.delay_before_even_handler_second = self._float(
+            delay_before_even_handler_second
+        )
+
+    def _set_percentage_simulate_failures(self, percentage_simulate_failures):
+        if percentage_simulate_failures is None:
+            percentage_simulate_failures = os.environ.get(
+                EVENT_CHAOS_PERCENTAGE_SIMULATE_FAILURES_KEY
+            )
+        self.percentage_simulate_failures = self._float(percentage_simulate_failures)
+
+    def _float(self, value):
+        return float(value) if value is not None else None
+
+    def __repr__(self):
+        return f"RabbitMqEventChaos: {self.info()}"
 
     def info(self) -> Dict:
         return {
