@@ -12,12 +12,19 @@ class RabbitMqEventConfigurerMother:
         return RabbitMqEventConfigurer(connector, DEFAULT_ORGANIZATION, DEFAULT_SERVICE)
 
     @staticmethod
-    def with_ttl_10ms(connector: RabbitMqConnector = None):
+    def with_retry_ttl_10ms(connector: RabbitMqConnector = None):
         connector = RabbitMqConnector() if not connector else connector
         return RabbitMqEventConfigurer(
             connector, DEFAULT_ORGANIZATION, DEFAULT_SERVICE, retry_ttl=10
         )
 
+    @staticmethod
+    def with_main_and_retry_ttl_10ms(connector: RabbitMqConnector = None):
+        connector = RabbitMqConnector() if not connector else connector
+        return RabbitMqEventConfigurer(
+            connector, DEFAULT_ORGANIZATION, DEFAULT_SERVICE, retry_ttl=10, main_ttl=10
+        )
+
     @staticmethod
     def with_service(service: str, connector: RabbitMqConnector = None):
         connector = RabbitMqConnector() if not connector else connector
